// Copyright (c) Mito
import React from 'react';
import '../../../css/elements/DropdownItem.css';
import { classNames } from '../../utils/classNames';
import { DROPDOWN_DISABLED_CLASS } from './Dropdown';
/**
 * The DropdownItem component is used to populate the Dropdown component.
 */
const DropdownItem = (props) => {
    const disabled = props.disabled === true;
    /*
        Stops the dropdown from closing when this item is selected.
        Note: We add this class to every element in the dropdown item
        because we're not sure which one will register the onClick event
    */
    const dropdownDisabledClass = disabled ? DROPDOWN_DISABLED_CLASS : '';
    const hideSubtext = props.hideSubtext === true;
    const displaySubtextOnHover = props.displaySubtextOnHover === true;
    return (React.createElement("div", { className: classNames('dropdown-item', dropdownDisabledClass, props.className), onClick: !disabled ? props.onClick : undefined },
        React.createElement("div", { className: classNames('dropdown-item-icon-and-title-container', dropdownDisabledClass) },
            React.createElement("div", { className: classNames('dropdown-item-icon-container', dropdownDisabledClass) }, props.icon),
            React.createElement("span", { title: props.title },
                React.createElement("p", { className: classNames('text-body-2', 'text-overflow-hide', dropdownDisabledClass, { 'dropdown-item-title-disabled': disabled }) }, props.title))),
        props.subtext &&
            /*
                If hideSubtext is true, then we only want to display the subtext if displaySubtextOnHover is true and the
                DropdownItem is hovered over
            */
            React.createElement("div", { className: classNames('dropdown-item-subtext-container', 'text-subtext-1', dropdownDisabledClass, { 'dropdown-item-subtext-disabled': disabled }, { 'dropdown-item-display-subtext-on-hover': hideSubtext && displaySubtextOnHover }) }, props.subtext)));
};
export default DropdownItem;
//# sourceMappingURL=DropdownItem.js.map